@@ -21,6 +21,8 @@ pub const INSTRUCTION_UPDATE_STATE_TEERTIARY:u8=17;
 pub const INSTRUCTION_UPDATE_STATE_AIRDROP_ACCOUNT:u8=18;
 pub const INSTRUCTION_INITIALIZE_PORTFOLIO:u8=19;
 pub const INSTRUCTION_CREATE_INIT_PPU:u8=20;
+pub const INSTRUCTION_CREATE_INIT_TURING_MASHINE:u8=38;
+pub const INSTRUCTION_CREATE_INIT_TRIGGUER_TURING_MASHINE:u8=39;
 pub const INSTRUCTION_UPDATE_STATE_INITIALIZE_PPM:u8=21;
 pub const INSTRUCTION_ADD_ASSET_TO_PORTFOLIO:u8=22;
 pub const INSTRUCTION_ADD_SPLU_TO_PPU:u8=23;
