@@ -5,5 +5,5 @@ pub mod nft;
 pub mod distribute_token;
 pub mod portfolio;
 pub mod user_portfolio;
-pub mod turing;
-pub mod turing_trigguer;
\ No newline at end of file
+pub mod turing_machine;
+pub mod trigguer_turing_machine;
\ No newline at end of file
