@@ -25,16 +25,18 @@ const VERSION_SIZE: usize = 1;
 #[repr(C)]
 #[derive(Clone, Debug, Default, PartialEq, Serialize, Deserialize)]
 pub struct SpluStateSecondaryStruct {
+    /// SPLU secondary address.
+    pub splu_secondary_address: Pubkey,
     /// State of SPLU secondary.
-    pub state_splu_secondary: u8,
+    pub splu_secondary_state: u8,
 }
 
 impl SpluStateSecondaryStruct {
 
     /// update the state of splu secondary
     pub fn update_state_splu_secondary(&mut self) -> ProgramResult {
-        self.state_splu_secondary = self
-            .state_splu_secondary
+        self.splu_secondary_state = self
+            .splu_secondary_state
             .checked_add(1)
             .ok_or(PortfolioError::InvalidState)?;
 
@@ -43,7 +45,7 @@ impl SpluStateSecondaryStruct {
 
     /// reset the state of splu secondary
     pub fn reset_splu_secondary(&mut self) -> ProgramResult {
-        self.state_splu_secondary = 0;
+        self.splu_secondary_state = 0;
 
         Ok(())
     }
@@ -53,7 +55,7 @@ impl SpluStateSecondaryStruct {
 /// Account data.
 #[repr(C)]
 #[derive(Clone, Debug, Default, PartialEq, Serialize, Deserialize)]
-pub struct TuringAccount {
+pub struct TuringMashineAccount {
     /// The type of account.
     pub type_account: u8,
     /// The owner of this account.
@@ -70,27 +72,27 @@ pub struct TuringAccount {
     pub splu_state_list: Vec<SpluStateSecondaryStruct>,
 }
 
-impl Sealed for TuringAccount {}
+impl Sealed for TuringMashineAccount {}
 
-impl IsInitialized for TuringAccount {
+impl IsInitialized for TuringMashineAccount {
     fn is_initialized(&self) -> bool {
         return self.type_account == TYPE_ACCOUNT_TURING_MASHINE_ACCOUNT;
     }
 }
 
 /// pack and unpack for turing account
-pub trait PackTuringAccount {
+pub trait PackTuringMashineAccount {
     /// unpack user portfolio
-    fn unpack_turing_account(src: &[u8]) -> Result<TuringAccount, ProgramError>;
+    fn unpack_turing_mashine_account(src: &[u8]) -> Result<TuringMashineAccount, ProgramError>;
     /// pack user portfolio
-    fn pack_turing_account(&self, dst: &mut [u8]);
+    fn pack_turing_mashine_account(&self, dst: &mut [u8]);
 }
 
-impl PackTuringAccount for TuringAccount {
+impl PackTuringMashineAccount for TuringMashineAccount {
  
     // unpack turing trigguer account
 
-        fn unpack_turing_account(src: &[u8]) -> Result<Self, ProgramError> {
+        fn unpack_turing_mashine_account(src: &[u8]) -> Result<Self, ProgramError> {
             let numbre_splu_state = (&src.len() - TURING_MASHINE_ACCOUNT_PREFIX) / SPLU_SECONDARY_STRUCT_LEN;
             let len_splu_data = &src.len() - TURING_MASHINE_ACCOUNT_PREFIX;
     
@@ -115,14 +117,17 @@ impl PackTuringAccount for TuringAccount {
         // unpack list of splu struct
         let mut offset = 0;
         for _ in 0..numbre_splu_state {
-            let state_splu_secondary = array_ref![list_splu_data, offset, SPLU_SECONDARY_STRUCT_LEN];
+            let splu_secondary = array_ref![list_splu_data, offset, SPLU_SECONDARY_STRUCT_LEN];
+            #[allow(clippy::ptr_offset_with_cast)]
+            let (splu_secondary_address , splu_secondary_state) = array_refs![splu_secondary, PUBKEY_SIZE, 1];
             splu_vec.push(SpluStateSecondaryStruct {
-                state_splu_secondary: u8::from_le_bytes(*state_splu_secondary)
+                splu_secondary_address: Pubkey::new_from_array(*splu_secondary_address),
+                splu_secondary_state: u8::from_le_bytes(*splu_secondary_state)
             });
             offset += SPLU_SECONDARY_STRUCT_LEN;
         }
 
-        Ok(TuringAccount {
+        Ok(TuringMashineAccount {
             type_account: u8::from_le_bytes(*type_account),
             owner: Pubkey::new_from_array(*owner),
             splm_n_asset: Pubkey::new_from_array(*splm_n_asset),
@@ -133,8 +138,8 @@ impl PackTuringAccount for TuringAccount {
             })
     }
 
-    // pack turing account
-    fn pack_turing_account(&self, dst: &mut [u8]) {
+    // pack turing mashine account
+    fn pack_turing_mashine_account(&self, dst: &mut [u8]) {
         let dst_tmp = array_mut_ref![dst, 0, TURING_MASHINE_ACCOUNT_PREFIX];
         let (
             type_account_dst,
@@ -152,7 +157,7 @@ impl PackTuringAccount for TuringAccount {
             AMOUNT_SIZE,
             VERSION_SIZE
         ];
-        let TuringAccount {
+        let TuringMashineAccount {
             type_account,
             owner,
             splm_n_asset,
@@ -196,12 +201,13 @@ mod tests {
         let version = 1;
         
         let splu_struct= SpluStateSecondaryStruct{
-            state_splu_secondary:0
+            splu_secondary_address:Pubkey::new_unique(),
+            splu_secondary_state:0
         };
 
         let mut splu_state_list = Vec::new();
         splu_state_list.push(splu_struct);
-        let turing = TuringAccount {
+        let turing = TuringMashineAccount {
             type_account,
             owner,
             splm_n_asset,
@@ -214,8 +220,8 @@ mod tests {
         const LEN: usize = TURING_MASHINE_ACCOUNT_PREFIX + (SPLU_SECONDARY_STRUCT_LEN * 1); // 204: @préfix + 164:splu_len * 1
         let mut packed = [0u8; LEN];
 
-        TuringAccount::pack_turing_account(&turing, &mut packed[..]);
-        let unpacked = TuringAccount::unpack_turing_account(&packed).unwrap();
+        TuringMashineAccount::pack_turing_mashine_account(&turing, &mut packed[..]);
+        let unpacked = TuringMashineAccount::unpack_turing_mashine_account(&packed).unwrap();
         assert_eq!(turing, unpacked);
         assert_eq!(unpacked.type_account, TYPE_ACCOUNT_TURING_MASHINE_ACCOUNT);
     }
